#
# spec file for package systemtap-dtrace
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif
Name:           systemtap-dtrace
Version:        5.2
Release:        1.1
Summary:        SystemTap dtrace utility
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
URL:            http://sourceware.org/systemtap/
Source0:        http://sourceware.org/systemtap/ftp/releases/systemtap-%{version}.tar.gz
Source1:        http://sourceware.org/systemtap/ftp/releases/systemtap-%{version}.tar.gz.asc
Source2:        systemtap.keyring
Source3:        README-BEFORE-ADDING-PATCHES
Source4:        README-KEYRING

BuildRequires:  python-rpm-macros
BuildArch:      noarch

%description
SystemTap is an instrumentation system for systems running Linux.
This package contains the dtrace utility to build provider and probe
definitions.

%prep
%setup -q -n systemtap-%{version}
%autopatch -p1

%build
# Our binutils always support '?' in the section characters on all
# architectures, no need for configure tests
sed s=@preferred_python@=%{_bindir}/python3= dtrace.in |sed s=@prefix@=%{_prefix}= >dtrace

%install
mkdir -p %{buildroot}%{_bindir}
install -m 755 dtrace %{buildroot}%{_bindir}
%python3_fix_shebang

%files
%defattr(-,root,root)
%{_bindir}/dtrace

%changelog
* Mon Feb 24 2025 Tony Jones <tonyj@suse.com>
- Upgrade to version 5.2. See systemtap.changes for changelog
* Mon Jun 17 2024 Tony Jones <tonyj@suse.com>
- Upgrade to version 5.1. See systemtap.changes for changelog
* Fri Mar  8 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Sat Dec 30 2023 Florian "sp1rit" <sp1rit@disroot.org>
- Upgrade to version 5.0. See systemtap.changed for changelog
* Tue Sep 13 2022 Tony Jones <tonyj@suse.com>
- Upgrade to version 4.7. See systemtap.spec for changelog
* Thu Apr 21 2022 Tony Jones <tonyj@suse.com>
- Remove unnecessary patches.  Only patches specific to dtrace are needed.
* Wed Mar  2 2022 Tony Jones <tonyj@suse.com>
- Add gcc12 support (bsc#1196583)
    New patch: PR28778-gcc-warning-tweak-for-sprintf-precision-parameter.patch
    New patch: gcc12-c-compatibility-tweak-use-lambdas-instead-of-ptr_fun.patch
    New patch: gcc12-c-compatibility-re-tweak-for-rhel6-use-function-pointer-instead-of-lambdas-instead-of-ptr_fun.patch
    New patch: buildrun-for-LKM-backend-add-Wno-infinite-recursion.patch
    New patch: gcc12-warning-suppression.patch
* Mon Feb 21 2022 Andreas Schwab <schwab@suse.de>
- Handle-user-supplied-sdt-probe-argument-template.patch: Fix glibc build
  failure on s390x
* Mon Feb 14 2022 Tony Jones <tonyj@suse.com>
- Resolve gcc compilation error reported against glib2 and libvirt
    New patch: sys-sdt.h-fp-constraints-arm32.patch
    New patch: sys-sdt.h-fp-constraints-x86_64.patch
    New patch: sys-sdt.h-fp-constraints-aarch64-s390.patch
- Add existing patch systemtap-build-source-dir.patch to spec for consistency
* Thu Jan 27 2022 Tony Jones <tonyj@suse.com>
- Upgrade to version 4.6. See systemtap.spec for changelog
* Fri Dec  6 2019 Tony Jones <tonyj@suse.com>
- Upgrade to version 4.2. See systemtap.spec for changelog
* Fri Sep 27 2019 Michael Gorse <mgorse@suse.com>
- Moved the dtrace binary into a separate package to resolve build
  cycle with glib2 (bsc#1145438).
